"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const logger_1 = require("./logger");
const rpc_state_manager_1 = require("./rpc-state-manager");
const rpc_1 = require("./rpc");
// Add ts-node registration before dynamic imports
require('ts-node').register({
    transpileOnly: true,
    compilerOptions: { module: 'commonjs' },
});
function parseArgs(arg) {
    try {
        return JSON.parse(arg);
    }
    catch {
        return arg;
    }
}
async function runTypescriptModule(filePath, args) {
    try {
        // Remove pathToFileURL since we'll use require
        const module = require(path_1.default.resolve(filePath));
        // Check if the specified function exists in the module
        if (typeof module.handler !== 'function') {
            throw new Error(`Function handler not found in module ${filePath}`);
        }
        const { stateConfig, ...event } = args;
        const { traceId, flows } = event;
        const logger = new logger_1.Logger(traceId, flows, filePath.split('/').pop());
        const sender = new rpc_1.RpcSender(process);
        const state = new rpc_state_manager_1.RpcStateManager(sender);
        const emit = async (data) => sender.send('emit', data);
        const context = { traceId, flows, logger, state, emit };
        sender.init();
        // Call the function with provided arguments
        await module.handler(event.data, context);
        process.exit(0);
    }
    catch (error) {
        console.error('Error running TypeScript module:', error);
        process.exit(1);
    }
}
const [, , filePath, arg] = process.argv;
if (!filePath) {
    console.error('Usage: node nodeRunner.js <file-path> <arg>');
    process.exit(1);
}
runTypescriptModule(filePath, parseArgs(arg)).catch((err) => {
    console.error('Error:', err);
    process.exit(1);
});
