"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStepHandlers = void 0;
const logger_1 = require("./logger");
const guards_1 = require("./guards");
const call_step_file_1 = require("./call-step-file");
const createStepHandlers = (steps, eventManager, state) => {
    logger_1.globalLogger.debug(`[step handler] creating step handlers for ${steps.length} steps`);
    steps.filter(guards_1.isEventStep).forEach((step) => {
        const { config, filePath } = step;
        const { subscribes } = config;
        logger_1.globalLogger.debug('[step handler] establishing step subscriptions', { filePath, step: step.config.name });
        subscribes.forEach((subscribe) => {
            eventManager.subscribe(subscribe, step.config.name, async (event) => {
                const { logger, ...rest } = event;
                logger_1.globalLogger.debug('[step handler] received event', { event: rest, step: step.config.name });
                try {
                    await (0, call_step_file_1.callStepFile)(filePath, step.config.name, event, eventManager, state);
                }
                catch (error) {
                    logger_1.globalLogger.error(`[step handler] error calling step`, {
                        error: error.message,
                        filePath,
                        step: step.config.name,
                    });
                }
            });
        });
    });
};
exports.createStepHandlers = createStepHandlers;
